import { Injectable } from "@nestjs/common";
import { BaseService } from "../base/base.service";
import { db, ObjectType, Prisma, UserProfile } from "@nice/common";
import EventBus, { CrudOperation } from "@server/utils/event-bus";
import { DefaultArgs } from "@prisma/client/runtime/library";

interface AgeRange {
    start: number | null;
    end: number | null;
    label: string;
  }
  
interface ScoreStandard {
    ageRanges: AgeRange[];
    scoreTable: {
      [score: string]: number[];
    }
  }

@Injectable()
export class sportProjectService extends BaseService<Prisma.SportProjectDelegate> {
    constructor() {
        super(db,ObjectType.SPORT_PROJECT,true);
    }
    async create(args: Prisma.SportProjectCreateArgs) {
        console.log(args)
        const result = await super.create(args)
        this.emitDataChanged(CrudOperation.CREATED,result)
        return result    
    }

    async update(args:Prisma.SportProjectUpdateArgs){
        const result = await super.update(args)
        this.emitDataChanged(CrudOperation.UPDATED,result)
        return result
    }


    async findMany(args: Prisma.SportProjectFindManyArgs) {
        const result = await super.findMany(args);
        return result;
    }

    private emitDataChanged(operation: CrudOperation, data: any) {
        EventBus.emit('dataChanged', {
          type:ObjectType.SPORT_STANDARD,
          operation,
          data,
        });
    }
}