import { Injectable } from "@nestjs/common";
import { TrpcService } from "@server/trpc/trpc.service";
import { SportStandardService } from "./sportStandard.service";
import { z, ZodType } from "zod";
import { Prisma } from "@nice/common";

const SportStandardArgsSchema:ZodType<Prisma.SportStandardCreateArgs> = z.any()
const SportStandardUpdateArgsSchema:ZodType<Prisma.SportStandardUpdateArgs> = z.any()
const SportStandardFindManyArgsSchema:ZodType<Prisma.SportStandardFindManyArgs> = z.any()
const SportStandardCreateStandardArgsSchema:ZodType<Prisma.SportStandardCreateArgs> = z.any()

interface AgeRange {
    start: number | null;
    end: number | null;
    label: string;
}
interface Record {
    [key: string]: number[];
}

@Injectable()
export class SportStandardRouter {
    constructor(
        private readonly trpc: TrpcService,
        private readonly sportStandardService: SportStandardService,
    ) { }

    router = this.trpc.router({
        // create:this.trpc.procedure.input(SportStandardArgsSchema)
        //     .mutation(async ({input})=>{
        //         return this.sportStandardService.create(input)
        //     }),
        update:this.trpc.procedure.input(SportStandardUpdateArgsSchema)
            .mutation(async ({input})=>{
                return this.sportStandardService.update(input)
            }),
        findMany:this.trpc.procedure.input(SportStandardFindManyArgsSchema)
            .query(async ({input})=>{
                return this.sportStandardService.findMany(input)
            }),
        createStandard:this.trpc.procedure.input(SportStandardCreateStandardArgsSchema)
            .mutation(async ({input})=>{
                const data = {
                    projectId: input.data.projectId,
                    gender: input.data.gender,
                    personType: input.data.personType,
                    ageRanges: input.data.ageRanges as any as AgeRange[],
                    scoreTable: input.data.scoreTable as Record
                }
                return this.sportStandardService.createStandard(data,input.select,input.include)
            })
    })

}